<?php
/**
 * Core hooks.
 *
 * @package WEN_Associate
 */

if ( ! function_exists( 'wen_associate_custom_body_class' ) ) :

	/**
	 * Custom body class.
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $input One or more classes to add to the class list.
	 * @return array Array of classes.
	 */
	function wen_associate_custom_body_class( $input ) {

		// Adds a class of group-blog to blogs with more than 1 published author.
		if ( is_multi_author() ) {
			$input[] = 'group-blog';
		}

		// Site layout.
		$site_layout = wen_associate_get_option( 'site_layout' );
		$input[] = 'site-layout-' . esc_attr( $site_layout );

		// Header layout.
		$header_layout = wen_associate_get_option( 'header_layout' );
		$input[] = 'header-' . esc_attr( $header_layout );

		// Sticky menu.
		$disable_sticky_primary_menu = wen_associate_get_option( 'disable_sticky_primary_menu' );
		if ( true !== $disable_sticky_primary_menu ) {
			$input[] = 'sticky-menu-enabled';
		}

		// Global layout.
		global $post;
		$global_layout = wen_associate_get_option( 'global_layout' );
		$global_layout = apply_filters( 'wen_associate_filter_theme_global_layout', $global_layout );

		// Check if single.
		if ( $post  && is_singular() ) {
			$post_options = get_post_meta( $post->ID, 'theme_settings', true );
			if ( isset( $post_options['post_layout'] ) && ! empty( $post_options['post_layout'] ) ) {
				$global_layout = $post_options['post_layout'];
			}
		}

		$input[] = 'global-layout-' . esc_attr( $global_layout );

		// Hide content condition.
		if (
		is_front_page() &&
		! is_active_sidebar( 'sidebar-front-page-main' ) &&
		! is_active_sidebar( 'sidebar-front-page-lower-left' ) &&
		! is_active_sidebar( 'sidebar-front-page-lower-right' ) &&
		is_active_sidebar( 'sidebar-front-page-bottom' )
		) {
			$input[] = 'hide-content';
		}

		return $input;
	}
endif;
add_filter( 'body_class', 'wen_associate_custom_body_class' );


if ( ! function_exists( 'wen_associate_custom_content_width' ) ) :

	/**
	 * Custom Content Width.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_custom_content_width() {

		global $post, $wp_query, $content_width;

		$global_layout = wen_associate_get_option( 'global_layout' );
		$global_layout = apply_filters( 'wen_associate_filter_theme_global_layout', $global_layout );

		// Check if single.
		if ( $post  && is_singular() ) {
			$post_options = get_post_meta( $post->ID, 'theme_settings', true );
			if ( isset( $post_options['post_layout'] ) && ! empty( $post_options['post_layout'] ) ) {
				$global_layout = $post_options['post_layout'];
			}
		}
		switch ( $global_layout ) {

			case 'no-sidebar':
				$content_width = 1170;
			break;

			case 'three-columns':
			case 'three-columns-pcs':
			case 'three-columns-cps':
			case 'three-columns-psc':
			case 'no-sidebar-centered':
				$content_width = 570;
			break;

			case 'three-columns-pcs-equal':
			case 'three-columns-scp-equal':
				$content_width = 370;
			break;

			case 'left-sidebar':
			case 'right-sidebar':
				$content_width = 770;
			break;

			default:
			break;
		}

	}
endif;

add_filter( 'template_redirect', 'wen_associate_custom_content_width' );


if ( ! function_exists( 'wen_associate_featured_image_instruction' ) ) :

	/**
	 * Message to show in the Featured Image Meta box.
	 *
	 * @since 1.0.0
	 *
	 * @param string $content Admin post thumbnail HTML markup.
	 * @param int    $post_id Post ID.
	 * @return string HTML.
	 */
	function wen_associate_featured_image_instruction( $content, $post_id ) {

		$allowed = array( 'post', 'page' );
		if ( in_array( get_post_type( $post_id ), $allowed ) ) {
			$content .= '<br/><strong>' . __( 'Recommended Image Sizes', 'wen-associate' ) . ':</strong><br/>';
			$content .= __( 'Featured Slider', 'wen-associate' ).' : 1300px X 440px';
		}

		return $content;

	}

endif;
add_filter( 'admin_post_thumbnail_html', 'wen_associate_featured_image_instruction', 10, 2 );

if ( ! function_exists( 'wen_associate_implement_excerpt_length' ) ) :

	/**
	 * Implement excerpt length
	 *
	 * @since 1.0.0
	 *
	 * @param int $length The number of words.
	 * @return int Excerpt length.
	 */
	function wen_associate_implement_excerpt_length( $length ) {

		$excerpt_length = wen_associate_get_option( 'excerpt_length' );
		if ( empty( $excerpt_length ) ) {
			$excerpt_length = $length;
		}
		return apply_filters( 'wen_associate_filter_excerpt_length', esc_attr( $excerpt_length ) );

	}

endif;

if ( ! function_exists( 'wen_associate_implement_read_more' ) ) :

	/**
	 * Implement read more in excerpt.
	 *
	 * @since 1.0.0
	 *
	 * @param string $more The string shown within the more link.
	 * @return string The excerpt.
	 */
	function wen_associate_implement_read_more( $more ) {

		$flag_apply_excerpt_read_more = apply_filters( 'wen_associate_filter_excerpt_read_more', true );
		if ( true !== $flag_apply_excerpt_read_more ) {
			return $more;
		}

		$output = $more;
		$read_more_text = wen_associate_get_option( 'read_more_text' );
		if ( ! empty( $read_more_text ) ) {
			$output = ' <a href="'. esc_url( get_permalink() ) . '" class="read-more">' . esc_html( $read_more_text ) . '</a>';
			$output = apply_filters( 'wen_associate_filter_read_more_link' , $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'wen_associate_content_more_link' ) ) :

	/**
	 * Implement read more in content.
	 *
	 * @since 1.0.0
	 *
	 * @param string $more_link Read More link element.
	 * @param string $more_link_text Read More text.
	 * @return string Link.
	 */
	function wen_associate_content_more_link( $more_link, $more_link_text ) {

		$flag_apply_excerpt_read_more = apply_filters( 'wen_associate_filter_excerpt_read_more', true );
		if ( true !== $flag_apply_excerpt_read_more ) {
			return $more_link;
		}

		$read_more_text = wen_associate_get_option( 'read_more_text' );
		if ( ! empty( $read_more_text ) ) {
			$more_link = str_replace( $more_link_text, esc_html( $read_more_text ), $more_link );
		}
		return $more_link;

	}

endif;

if ( ! function_exists( 'wen_associate_exclude_category_in_blog_page' ) ) :

	/**
	 * Exclude category in blog page.
	 *
	 * @since  WEN Associate 1.0
	 *
	 * @param WP_Query $query The WP_Query instance (passed by reference).
	 */
	function wen_associate_exclude_category_in_blog_page( $query ) {

		if ( $query->is_home && $query->is_main_query()   ) {
			$exclude_categories = wen_associate_get_option( 'exclude_categories' );
			if ( ! empty( $exclude_categories ) ) {
				$cats = explode( ',', $exclude_categories );
				$cats = array_filter( $cats, 'is_numeric' );
				$string_exclude = '';
				if ( ! empty( $cats ) ) {
					$string_exclude = '-' . implode( ',-', $cats );
					$query->set( 'cat', $string_exclude );
				}
			}
		}
		return $query;

	}

endif;

add_filter( 'pre_get_posts', 'wen_associate_exclude_category_in_blog_page' );

if ( ! function_exists( 'wen_associate_hook_read_more_filters' ) ) :

	/**
	 * Hook read more filters.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_hook_read_more_filters() {
		if ( is_home() || is_category() || is_tag() || is_author() || is_date() ) {
			add_filter( 'excerpt_length', 'wen_associate_implement_excerpt_length', 999 );
			add_filter( 'excerpt_more', 'wen_associate_implement_read_more' );
			add_filter( 'the_content_more_link', 'wen_associate_content_more_link', 10, 2 );
		}
	}
endif;

add_action( 'wp', 'wen_associate_hook_read_more_filters' );

if ( ! function_exists( 'wen_associate_import_custom_css' ) ) :

	/**
	 * Import Custom CSS.
	 *
	 * @since 2.0.0
	 */
	function wen_associate_import_custom_css() {

		// Bail if not WP 4.7.
		if ( ! function_exists( 'wp_get_custom_css_post' ) ) {
			return;
		}

		$custom_css = wen_associate_get_option( 'custom_css' );

		// Bail if there is no Custom CSS.
		if ( empty( $custom_css ) ) {
			return;
		}

		$core_css = wp_get_custom_css();
		$return = wp_update_custom_css_post( $core_css . $custom_css );

		if ( ! is_wp_error( $return ) ) {

			// Remove from theme.
			$options = wen_associate_get_options();
			$options['custom_css'] = '';
			set_theme_mod( 'theme_options', $options );
		}

	}
endif;

add_action( 'after_setup_theme', 'wen_associate_import_custom_css', 99 );

if ( ! function_exists( 'wen_associate_customizer_reset_callback' ) ) :

	/**
	 * Callback for reset in Customizer.
	 *
	 * @since 2.0.0
	 */
	function wen_associate_customizer_reset_callback() {

		$reset_all_settings = wen_associate_get_option( 'reset_all_settings' );

		if ( true === $reset_all_settings ) {

			// Reset custom theme options.
			set_theme_mod( 'theme_options', array() );

			// Reset custom header, logo and backgrounds.
			remove_theme_mod( 'custom_logo' );
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
		}

		// Reset color options.
		$reset_color_settings = wen_associate_get_option( 'reset_all_color_settings' );
		if ( true === $reset_color_settings ) {
			$options = wen_associate_get_options();
			$options['reset_all_color_settings'] = false;
			$color_settings = wen_associate_get_default_colors();
			if ( ! empty( $color_settings ) ) {
				foreach ( $color_settings as $key => $val ) {
					$options[ $key ] = $val;
				}
				set_theme_mod( 'theme_options', $options );
			}
			remove_theme_mod( 'background_color' );
		}

		// Reset font options.
		$reset_font_settings = wen_associate_get_option( 'reset_font_settings' );
		if ( true === $reset_font_settings ) {
			$options  = wen_associate_get_options();
			$font_settings = wen_associate_get_font_family_theme_settings_options();
			$options['reset_font_settings'] = false;
			if ( ! empty( $font_settings ) ) {
				foreach ( $font_settings as $key => $val ) {
					$options[ $key ] = $val['default'];
				}
				set_theme_mod( 'theme_options', $options );
			}
		}

		// Reset footer content.
		$reset_footer_content = wen_associate_get_option( 'reset_footer_content' );
		if ( true === $reset_footer_content ) {
			$options = wen_associate_get_options();
			$defaults = wen_associate_get_default_theme_options();
			$options['reset_footer_content'] = false;
			$options['copyright_text'] = $defaults['copyright_text'];
			$options['powered_by_text'] = $defaults['powered_by_text'];
			set_theme_mod( 'theme_options', $options );
		}

	}
endif;

add_action( 'customize_save_after', 'wen_associate_customizer_reset_callback' );

/**
 * Load theme options from free theme.
 *
 * Checks if there are options already present from free version and adds it to the Pro theme options.
 *
 * @since 2.0.0
 */
function wen_associate_import_free_options() {

	// Perform action only if theme_mods_XXX[theme_options] does not exist.
	if( ! get_theme_mod( 'theme_options' ) ) {

		// Perform action only if theme_mods_XXX free version exists.
		if ( $free_options = get_option ( 'theme_mods_wen-associate' ) ) {
			if ( isset( $free_options['theme_options'] ) ) {

				$pro_default_options = wen_associate_get_default_theme_options();

				$pro_theme_options = $free_options;

				$pro_theme_options['theme_options'] = array_merge( $pro_default_options , $free_options['theme_options'] );

				// WP default fields.
				$fields = array(
					'custom_logo',
					'header_image',
					'header_image_data',
					'background_color',
					'background_image',
					'background_repeat',
					'background_position_x',
					'background_attachment',
				);

				foreach ( $fields as $key ) {
					if ( isset( $free_options[ $key ] ) && ! empty( $free_options[ $key ] ) ) {
						$pro_theme_options[ $key ] = $free_options[ $key ];
					}
				}

				update_option( 'theme_mods_wen-associate-pro', $pro_theme_options );
			}

		}
	}
}

add_action( 'after_switch_theme', 'wen_associate_import_free_options' );
